@@ -2,28 +2,33 @@ package Log::Facile;
 
 use strict;
 use vars qw($VERSION);
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 use Carp;
 
-use base qw( Class::Accessor::Fast );
-__PACKAGE__->mk_accessors(
-    qw( file debug_flag )
-);
-
 sub new {
     my ($class, $log_file) = @_;
     bless { 
-        file => $log_file 
+        log_file => $log_file 
     }, $class;
 }
 
+sub get {
+    my ($self, $name) = @_;
+    return $self->{$name};
+}
+
+sub set {
+    my ($self, $name, $value) = @_;
+    $self->{$name} = $value;
+}
+
 sub _write {
     my($self, $level, $message) = @_;
     my $date = $self->_current_date();
     my $log_mes = $date.' ['.$level.'] '.$message."\n";
 
-    open my $log, ">> ".$self->file or croak $!;
+    open my $log, ">> ".$self->get('log_file') or croak $!;
     print $log $log_mes;
     close $log or croak $!;
 }
@@ -46,11 +51,45 @@ sub error {
 }
 
 sub swap {
-    # TODO
+    my $self = shift;
+
+    # get log filename prefix
+    my $file_pref = $self->{log_file};
+    if ( $file_pref =~ m/.+\/(.+?)$/ ) {
+         $file_pref =~ s/.+\/(.+?)$/$1/;
+    }
+
+    # move current log file
+    if ( -f $self->{log_file} ) { 
+        rename $self->{log_file}, $self->{swap_dir}.'/'.$file_pref 
+            or croak 'current file move error - '.$!;
+    } else {
+        return 1;
+    }
+
+    # rename files
+    opendir my $s_dir, $self->{swap_dir} or croak 'dir open error - '.$!;
+    for my $each (grep /$file_pref/, reverse sort readdir $s_dir) {
+        $each = $self->{swap_dir}.'/'.$each;
+        my $rename_pref = $self->{swap_dir}.'/'.$file_pref.'.';
+        if ($each =~ /\.(\d)$/) {
+            rename $each, $rename_pref.($1+1) 
+                or croak 'rename error ('.$rename_pref.($1+1).') - '.$!;
+        } else {
+            rename $each, $rename_pref.'1' 
+                or croak 'rename error ('.$rename_pref.'.1) - '.$!;
+        }
+    }
+    closedir $s_dir or croak 'dir close error - '.$!;
 }
 
 sub _current_date {
     my($self, $pat) = @_;
+
+    my $format = $self->get('date_format');
+
+    # TODO customize format
+
     my @da = localtime(time);
     return sprintf("%04d/%02d/%02d %02d:%02d:%02d",
                    $da[5]+1900, $da[4]+1, $da[3], $da[2], $da[1], $da[0]);
@@ -67,7 +106,7 @@ Log::Facile - Perl extension for facile logging
 
   use Log::Facile;
 
-  my $logger = Log::Facile->new("tmp.log");
+  my $logger = Log::Facile->new('/foo/var/log/tmp.log');
   $logger->info('Log::Facile instance created!');
   $logger->debug('flag off');
   $logger->error('error occurred! detail.......');
@@ -81,17 +120,22 @@ This sample puts following logging.
   2008/08/25 01:01:49 [ERROR] error occurred! detail.......
   2008/08/25 01:01:49 [DEBUG] flag on
 
+Log swapping sample is following.
+
+  $logger->set('swap_dir', '/foo/var/log/old');
+  $logger->swap();
+
+This time swapped log filename is 'tmp.log.1'.
+This file will be renamed 'tmp.log.2' while upcoming log swapping.
+I mean, the incremented number means older.
+
 =head1 DESCRIPTION
 
 Log::Facile provides so facile logging that is intended for personal tools.
 
-=head2 TODO
-
-log swapping, more tests.
-
 =head1 AUTHOR
 
-Kazuhiro Sera, E<lt>webmaster@seratch.ath.cxE<gt>
+Kazuhiro Sera, E<lt>webmaster@seratch.netE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
